@@ -188,7 +188,9 @@ class PagarmePayment(models.Model):
         :return:
         """
         payment_method = pagarme_json['payment_method']
-        payment = cls(payment_method=payment_method, amount=pagarme_json['authorized_amount'], card_last_digits=pagarme_json['card_last_digits'], installments=pagarme_json['installments'], transaction_id=str(pagarme_json['id']))
+        payment = cls(payment_method=payment_method, amount=pagarme_json['authorized_amount'],
+                      card_last_digits=pagarme_json['card_last_digits'], installments=pagarme_json['installments'],
+                      transaction_id=str(pagarme_json['id']))
         if payment_method == CREDIT_CARD:
             payment.card_id = pagarme_json['card']['id']
 
@@ -364,7 +366,7 @@ class UserPaymentProfile(models.Model):
             email=customer['email'],
             phone=customer['phone_numbers'][-1].replace('+', ''),
             street=address['street'],
-            complementary=address['complementary'],
+            complementary=address.get('complementary', '') or '',
             street_number=address['street_number'],
             neighborhood=address['neighborhood'],
             city=address['city'],
