@@ -106,6 +106,8 @@ def pagarme(request, slug):
         'open_modal': open_modal,
         'customer': customer,
         'slug': slug,
-        'address': address
     }
+
+    if address is not None:
+        ctx['address'] = address
     return render(request, 'django_pagarme/pagarme.html', ctx)
